"""
Generated class for Task. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Address import *
from fhirmodels.R5.Age import *
from fhirmodels.R5.Annotation import *
from fhirmodels.R5.Attachment import *
from fhirmodels.R5.Availability import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.ContactPoint import *
from fhirmodels.R5.Count import *
from fhirmodels.R5.DataRequirement import *
from fhirmodels.R5.Distance import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Dosage import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Expression import *
from fhirmodels.R5.ExtendedContactDetail import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.HumanName import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Money import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.ParameterDefinition import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Ratio import *
from fhirmodels.R5.RatioRange import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.RelatedArtifact import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.SampledData import *
from fhirmodels.R5.Signature import *
from fhirmodels.R5.Timing import *
from fhirmodels.R5.TriggerDefinition import *
from fhirmodels.R5.UsageContext import *


class Performer(FhirBaseModel):
    """The entity who performed the requested task.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Type of performance
    :param Reference actor: Who performed the task
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "Task":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Task":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Restriction(FhirBaseModel):
    """If the Task.focus is a request resource and the task is seeking fulfillment (i.e. is asking for the request to be actioned), this element identifies any limitations on what parts of the referenced request should be actioned.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int repetitions: How many times to repeat
    :param Period period: When fulfillment is sought
    :param Reference recipient: For whom is fulfillment sought?
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "recipient": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        repetitions: "int" = None,
        period: "Period" = None,
        recipient: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.repetitions = repetitions
        self.period = period
        self.recipient = recipient or []

    @classmethod
    def from_dict(cls, data: dict) -> "Task":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Task":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Input(FhirBaseModel):
    """Additional information that may be needed in the execution of the task.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Label for the input
    :param str valueBase64Binary: Content to use in performing the task
    :param bool valueBoolean: Content to use in performing the task
    :param str valueCanonical: Content to use in performing the task
    :param str valueCode: Content to use in performing the task
    :param str valueDate: Content to use in performing the task
    :param str valueDateTime: Content to use in performing the task
    :param float valueDecimal: Content to use in performing the task
    :param str valueId: Content to use in performing the task
    :param str valueInstant: Content to use in performing the task
    :param int valueInteger: Content to use in performing the task
    :param int valueInteger64: Content to use in performing the task
    :param str valueMarkdown: Content to use in performing the task
    :param str valueOid: Content to use in performing the task
    :param int valuePositiveInt: Content to use in performing the task
    :param str valueString: Content to use in performing the task
    :param str valueTime: Content to use in performing the task
    :param int valueUnsignedInt: Content to use in performing the task
    :param str valueUri: Content to use in performing the task
    :param str valueUrl: Content to use in performing the task
    :param str valueUuid: Content to use in performing the task
    :param Address valueAddress: Content to use in performing the task
    :param Age valueAge: Content to use in performing the task
    :param Annotation valueAnnotation: Content to use in performing the task
    :param Attachment valueAttachment: Content to use in performing the task
    :param CodeableConcept valueCodeableConcept: Content to use in performing the task
    :param CodeableReference valueCodeableReference: Content to use in performing the task
    :param Coding valueCoding: Content to use in performing the task
    :param ContactPoint valueContactPoint: Content to use in performing the task
    :param Count valueCount: Content to use in performing the task
    :param Distance valueDistance: Content to use in performing the task
    :param Duration valueDuration: Content to use in performing the task
    :param HumanName valueHumanName: Content to use in performing the task
    :param Identifier valueIdentifier: Content to use in performing the task
    :param Money valueMoney: Content to use in performing the task
    :param Period valuePeriod: Content to use in performing the task
    :param Quantity valueQuantity: Content to use in performing the task
    :param Range valueRange: Content to use in performing the task
    :param Ratio valueRatio: Content to use in performing the task
    :param RatioRange valueRatioRange: Content to use in performing the task
    :param Reference valueReference: Content to use in performing the task
    :param SampledData valueSampledData: Content to use in performing the task
    :param Signature valueSignature: Content to use in performing the task
    :param Timing valueTiming: Content to use in performing the task
    :param ContactDetail valueContactDetail: Content to use in performing the task
    :param DataRequirement valueDataRequirement: Content to use in performing the task
    :param Expression valueExpression: Content to use in performing the task
    :param ParameterDefinition valueParameterDefinition: Content to use in performing the task
    :param RelatedArtifact valueRelatedArtifact: Content to use in performing the task
    :param TriggerDefinition valueTriggerDefinition: Content to use in performing the task
    :param UsageContext valueUsageContext: Content to use in performing the task
    :param Availability valueAvailability: Content to use in performing the task
    :param ExtendedContactDetail valueExtendedContactDetail: Content to use in performing the task
    :param Dosage valueDosage: Content to use in performing the task
    :param Meta valueMeta: Content to use in performing the task
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueAddress": {"class_name": "Address", "is_contained": False},
        "valueAge": {"class_name": "Age", "is_contained": False},
        "valueAnnotation": {"class_name": "Annotation", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueCodeableReference": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "valueCoding": {"class_name": "Coding", "is_contained": False},
        "valueContactPoint": {"class_name": "ContactPoint", "is_contained": False},
        "valueCount": {"class_name": "Count", "is_contained": False},
        "valueDistance": {"class_name": "Distance", "is_contained": False},
        "valueDuration": {"class_name": "Duration", "is_contained": False},
        "valueHumanName": {"class_name": "HumanName", "is_contained": False},
        "valueIdentifier": {"class_name": "Identifier", "is_contained": False},
        "valueMoney": {"class_name": "Money", "is_contained": False},
        "valuePeriod": {"class_name": "Period", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueRatio": {"class_name": "Ratio", "is_contained": False},
        "valueRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
        "valueSampledData": {"class_name": "SampledData", "is_contained": False},
        "valueSignature": {"class_name": "Signature", "is_contained": False},
        "valueTiming": {"class_name": "Timing", "is_contained": False},
        "valueContactDetail": {"class_name": "ContactDetail", "is_contained": False},
        "valueDataRequirement": {
            "class_name": "DataRequirement",
            "is_contained": False,
        },
        "valueExpression": {"class_name": "Expression", "is_contained": False},
        "valueParameterDefinition": {
            "class_name": "ParameterDefinition",
            "is_contained": False,
        },
        "valueRelatedArtifact": {
            "class_name": "RelatedArtifact",
            "is_contained": False,
        },
        "valueTriggerDefinition": {
            "class_name": "TriggerDefinition",
            "is_contained": False,
        },
        "valueUsageContext": {"class_name": "UsageContext", "is_contained": False},
        "valueAvailability": {"class_name": "Availability", "is_contained": False},
        "valueExtendedContactDetail": {
            "class_name": "ExtendedContactDetail",
            "is_contained": False,
        },
        "valueDosage": {"class_name": "Dosage", "is_contained": False},
        "valueMeta": {"class_name": "Meta", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueBase64Binary: "str" = None,
        valueBoolean: "bool" = None,
        valueCanonical: "str" = None,
        valueCode: "str" = None,
        valueDate: "str" = None,
        valueDateTime: "str" = None,
        valueDecimal: "float" = None,
        valueId: "str" = None,
        valueInstant: "str" = None,
        valueInteger: "int" = None,
        valueInteger64: "int" = None,
        valueMarkdown: "str" = None,
        valueOid: "str" = None,
        valuePositiveInt: "int" = None,
        valueString: "str" = None,
        valueTime: "str" = None,
        valueUnsignedInt: "int" = None,
        valueUri: "str" = None,
        valueUrl: "str" = None,
        valueUuid: "str" = None,
        valueAddress: "Address" = None,
        valueAge: "Age" = None,
        valueAnnotation: "Annotation" = None,
        valueAttachment: "Attachment" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueCodeableReference: "CodeableReference" = None,
        valueCoding: "Coding" = None,
        valueContactPoint: "ContactPoint" = None,
        valueCount: "Count" = None,
        valueDistance: "Distance" = None,
        valueDuration: "Duration" = None,
        valueHumanName: "HumanName" = None,
        valueIdentifier: "Identifier" = None,
        valueMoney: "Money" = None,
        valuePeriod: "Period" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        valueRatio: "Ratio" = None,
        valueRatioRange: "RatioRange" = None,
        valueReference: "Reference" = None,
        valueSampledData: "SampledData" = None,
        valueSignature: "Signature" = None,
        valueTiming: "Timing" = None,
        valueContactDetail: "ContactDetail" = None,
        valueDataRequirement: "DataRequirement" = None,
        valueExpression: "Expression" = None,
        valueParameterDefinition: "ParameterDefinition" = None,
        valueRelatedArtifact: "RelatedArtifact" = None,
        valueTriggerDefinition: "TriggerDefinition" = None,
        valueUsageContext: "UsageContext" = None,
        valueAvailability: "Availability" = None,
        valueExtendedContactDetail: "ExtendedContactDetail" = None,
        valueDosage: "Dosage" = None,
        valueMeta: "Meta" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueBase64Binary = valueBase64Binary
        self.valueBoolean = valueBoolean
        self.valueCanonical = valueCanonical
        self.valueCode = valueCode
        self.valueDate = valueDate
        self.valueDateTime = valueDateTime
        self.valueDecimal = valueDecimal
        self.valueId = valueId
        self.valueInstant = valueInstant
        self.valueInteger = valueInteger
        self.valueInteger64 = valueInteger64
        self.valueMarkdown = valueMarkdown
        self.valueOid = valueOid
        self.valuePositiveInt = valuePositiveInt
        self.valueString = valueString
        self.valueTime = valueTime
        self.valueUnsignedInt = valueUnsignedInt
        self.valueUri = valueUri
        self.valueUrl = valueUrl
        self.valueUuid = valueUuid
        self.valueAddress = valueAddress
        self.valueAge = valueAge
        self.valueAnnotation = valueAnnotation
        self.valueAttachment = valueAttachment
        self.valueCodeableConcept = valueCodeableConcept
        self.valueCodeableReference = valueCodeableReference
        self.valueCoding = valueCoding
        self.valueContactPoint = valueContactPoint
        self.valueCount = valueCount
        self.valueDistance = valueDistance
        self.valueDuration = valueDuration
        self.valueHumanName = valueHumanName
        self.valueIdentifier = valueIdentifier
        self.valueMoney = valueMoney
        self.valuePeriod = valuePeriod
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.valueRatio = valueRatio
        self.valueRatioRange = valueRatioRange
        self.valueReference = valueReference
        self.valueSampledData = valueSampledData
        self.valueSignature = valueSignature
        self.valueTiming = valueTiming
        self.valueContactDetail = valueContactDetail
        self.valueDataRequirement = valueDataRequirement
        self.valueExpression = valueExpression
        self.valueParameterDefinition = valueParameterDefinition
        self.valueRelatedArtifact = valueRelatedArtifact
        self.valueTriggerDefinition = valueTriggerDefinition
        self.valueUsageContext = valueUsageContext
        self.valueAvailability = valueAvailability
        self.valueExtendedContactDetail = valueExtendedContactDetail
        self.valueDosage = valueDosage
        self.valueMeta = valueMeta

    @classmethod
    def from_dict(cls, data: dict) -> "Task":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Task":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Output(FhirBaseModel):
    """Outputs produced by the Task.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Label for output
    :param str valueBase64Binary: Result of output
    :param bool valueBoolean: Result of output
    :param str valueCanonical: Result of output
    :param str valueCode: Result of output
    :param str valueDate: Result of output
    :param str valueDateTime: Result of output
    :param float valueDecimal: Result of output
    :param str valueId: Result of output
    :param str valueInstant: Result of output
    :param int valueInteger: Result of output
    :param int valueInteger64: Result of output
    :param str valueMarkdown: Result of output
    :param str valueOid: Result of output
    :param int valuePositiveInt: Result of output
    :param str valueString: Result of output
    :param str valueTime: Result of output
    :param int valueUnsignedInt: Result of output
    :param str valueUri: Result of output
    :param str valueUrl: Result of output
    :param str valueUuid: Result of output
    :param Address valueAddress: Result of output
    :param Age valueAge: Result of output
    :param Annotation valueAnnotation: Result of output
    :param Attachment valueAttachment: Result of output
    :param CodeableConcept valueCodeableConcept: Result of output
    :param CodeableReference valueCodeableReference: Result of output
    :param Coding valueCoding: Result of output
    :param ContactPoint valueContactPoint: Result of output
    :param Count valueCount: Result of output
    :param Distance valueDistance: Result of output
    :param Duration valueDuration: Result of output
    :param HumanName valueHumanName: Result of output
    :param Identifier valueIdentifier: Result of output
    :param Money valueMoney: Result of output
    :param Period valuePeriod: Result of output
    :param Quantity valueQuantity: Result of output
    :param Range valueRange: Result of output
    :param Ratio valueRatio: Result of output
    :param RatioRange valueRatioRange: Result of output
    :param Reference valueReference: Result of output
    :param SampledData valueSampledData: Result of output
    :param Signature valueSignature: Result of output
    :param Timing valueTiming: Result of output
    :param ContactDetail valueContactDetail: Result of output
    :param DataRequirement valueDataRequirement: Result of output
    :param Expression valueExpression: Result of output
    :param ParameterDefinition valueParameterDefinition: Result of output
    :param RelatedArtifact valueRelatedArtifact: Result of output
    :param TriggerDefinition valueTriggerDefinition: Result of output
    :param UsageContext valueUsageContext: Result of output
    :param Availability valueAvailability: Result of output
    :param ExtendedContactDetail valueExtendedContactDetail: Result of output
    :param Dosage valueDosage: Result of output
    :param Meta valueMeta: Result of output
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueAddress": {"class_name": "Address", "is_contained": False},
        "valueAge": {"class_name": "Age", "is_contained": False},
        "valueAnnotation": {"class_name": "Annotation", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueCodeableReference": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "valueCoding": {"class_name": "Coding", "is_contained": False},
        "valueContactPoint": {"class_name": "ContactPoint", "is_contained": False},
        "valueCount": {"class_name": "Count", "is_contained": False},
        "valueDistance": {"class_name": "Distance", "is_contained": False},
        "valueDuration": {"class_name": "Duration", "is_contained": False},
        "valueHumanName": {"class_name": "HumanName", "is_contained": False},
        "valueIdentifier": {"class_name": "Identifier", "is_contained": False},
        "valueMoney": {"class_name": "Money", "is_contained": False},
        "valuePeriod": {"class_name": "Period", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueRatio": {"class_name": "Ratio", "is_contained": False},
        "valueRatioRange": {"class_name": "RatioRange", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
        "valueSampledData": {"class_name": "SampledData", "is_contained": False},
        "valueSignature": {"class_name": "Signature", "is_contained": False},
        "valueTiming": {"class_name": "Timing", "is_contained": False},
        "valueContactDetail": {"class_name": "ContactDetail", "is_contained": False},
        "valueDataRequirement": {
            "class_name": "DataRequirement",
            "is_contained": False,
        },
        "valueExpression": {"class_name": "Expression", "is_contained": False},
        "valueParameterDefinition": {
            "class_name": "ParameterDefinition",
            "is_contained": False,
        },
        "valueRelatedArtifact": {
            "class_name": "RelatedArtifact",
            "is_contained": False,
        },
        "valueTriggerDefinition": {
            "class_name": "TriggerDefinition",
            "is_contained": False,
        },
        "valueUsageContext": {"class_name": "UsageContext", "is_contained": False},
        "valueAvailability": {"class_name": "Availability", "is_contained": False},
        "valueExtendedContactDetail": {
            "class_name": "ExtendedContactDetail",
            "is_contained": False,
        },
        "valueDosage": {"class_name": "Dosage", "is_contained": False},
        "valueMeta": {"class_name": "Meta", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueBase64Binary: "str" = None,
        valueBoolean: "bool" = None,
        valueCanonical: "str" = None,
        valueCode: "str" = None,
        valueDate: "str" = None,
        valueDateTime: "str" = None,
        valueDecimal: "float" = None,
        valueId: "str" = None,
        valueInstant: "str" = None,
        valueInteger: "int" = None,
        valueInteger64: "int" = None,
        valueMarkdown: "str" = None,
        valueOid: "str" = None,
        valuePositiveInt: "int" = None,
        valueString: "str" = None,
        valueTime: "str" = None,
        valueUnsignedInt: "int" = None,
        valueUri: "str" = None,
        valueUrl: "str" = None,
        valueUuid: "str" = None,
        valueAddress: "Address" = None,
        valueAge: "Age" = None,
        valueAnnotation: "Annotation" = None,
        valueAttachment: "Attachment" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueCodeableReference: "CodeableReference" = None,
        valueCoding: "Coding" = None,
        valueContactPoint: "ContactPoint" = None,
        valueCount: "Count" = None,
        valueDistance: "Distance" = None,
        valueDuration: "Duration" = None,
        valueHumanName: "HumanName" = None,
        valueIdentifier: "Identifier" = None,
        valueMoney: "Money" = None,
        valuePeriod: "Period" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        valueRatio: "Ratio" = None,
        valueRatioRange: "RatioRange" = None,
        valueReference: "Reference" = None,
        valueSampledData: "SampledData" = None,
        valueSignature: "Signature" = None,
        valueTiming: "Timing" = None,
        valueContactDetail: "ContactDetail" = None,
        valueDataRequirement: "DataRequirement" = None,
        valueExpression: "Expression" = None,
        valueParameterDefinition: "ParameterDefinition" = None,
        valueRelatedArtifact: "RelatedArtifact" = None,
        valueTriggerDefinition: "TriggerDefinition" = None,
        valueUsageContext: "UsageContext" = None,
        valueAvailability: "Availability" = None,
        valueExtendedContactDetail: "ExtendedContactDetail" = None,
        valueDosage: "Dosage" = None,
        valueMeta: "Meta" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueBase64Binary = valueBase64Binary
        self.valueBoolean = valueBoolean
        self.valueCanonical = valueCanonical
        self.valueCode = valueCode
        self.valueDate = valueDate
        self.valueDateTime = valueDateTime
        self.valueDecimal = valueDecimal
        self.valueId = valueId
        self.valueInstant = valueInstant
        self.valueInteger = valueInteger
        self.valueInteger64 = valueInteger64
        self.valueMarkdown = valueMarkdown
        self.valueOid = valueOid
        self.valuePositiveInt = valuePositiveInt
        self.valueString = valueString
        self.valueTime = valueTime
        self.valueUnsignedInt = valueUnsignedInt
        self.valueUri = valueUri
        self.valueUrl = valueUrl
        self.valueUuid = valueUuid
        self.valueAddress = valueAddress
        self.valueAge = valueAge
        self.valueAnnotation = valueAnnotation
        self.valueAttachment = valueAttachment
        self.valueCodeableConcept = valueCodeableConcept
        self.valueCodeableReference = valueCodeableReference
        self.valueCoding = valueCoding
        self.valueContactPoint = valueContactPoint
        self.valueCount = valueCount
        self.valueDistance = valueDistance
        self.valueDuration = valueDuration
        self.valueHumanName = valueHumanName
        self.valueIdentifier = valueIdentifier
        self.valueMoney = valueMoney
        self.valuePeriod = valuePeriod
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.valueRatio = valueRatio
        self.valueRatioRange = valueRatioRange
        self.valueReference = valueReference
        self.valueSampledData = valueSampledData
        self.valueSignature = valueSignature
        self.valueTiming = valueTiming
        self.valueContactDetail = valueContactDetail
        self.valueDataRequirement = valueDataRequirement
        self.valueExpression = valueExpression
        self.valueParameterDefinition = valueParameterDefinition
        self.valueRelatedArtifact = valueRelatedArtifact
        self.valueTriggerDefinition = valueTriggerDefinition
        self.valueUsageContext = valueUsageContext
        self.valueAvailability = valueAvailability
        self.valueExtendedContactDetail = valueExtendedContactDetail
        self.valueDosage = valueDosage
        self.valueMeta = valueMeta

    @classmethod
    def from_dict(cls, data: dict) -> "Task":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Task":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Task(DomainResource):
    """A task to be performed.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Task Instance Identifier
    :param str instantiatesCanonical: Formal definition of task
    :param str instantiatesUri: Formal definition of task
    :param Reference basedOn: Request fulfilled by this task
    :param Identifier groupIdentifier: Requisition or grouper id
    :param Reference partOf: Composite task
    :param str status: draft | requested | received | accepted | +
    :param CodeableReference statusReason: Reason for current status
    :param CodeableConcept businessStatus: E.g. "Specimen collected", "IV prepped"
    :param str intent: unknown | proposal | plan | order | original-order | reflex-order | filler-order | instance-order | option
    :param str priority: routine | urgent | asap | stat
    :param bool doNotPerform: True if Task is prohibiting action
    :param CodeableConcept code: Task Type
    :param str description: Human-readable explanation of task
    :param Reference focus: What task is acting on
    :param Reference _for: Beneficiary of the Task
    :param Reference encounter: Healthcare event during which this task originated
    :param Period requestedPeriod: When the task should be performed
    :param Period executionPeriod: Start and end time of execution
    :param str authoredOn: Task Creation Date
    :param str lastModified: Task Last Modified Date
    :param Reference requester: Who is asking for task to be done
    :param CodeableReference requestedPerformer: Who should perform Task
    :param Reference owner: Responsible individual
    :param Performer performer: Who or what performed the task
    :param Reference location: Where task occurs
    :param CodeableReference reason: Why task is needed
    :param Reference insurance: Associated insurance coverage
    :param Annotation note: Comments made about the task
    :param Reference relevantHistory: Key events in history of the Task
    :param Restriction restriction: Constraints on fulfillment tasks
    :param Input input: Information used to perform task
    :param Output output: Information produced as part of task
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "groupIdentifier": {"class_name": "Identifier", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "statusReason": {"class_name": "CodeableReference", "is_contained": False},
        "businessStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "focus": {"class_name": "Reference", "is_contained": False},
        "_for": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "requestedPeriod": {"class_name": "Period", "is_contained": False},
        "executionPeriod": {"class_name": "Period", "is_contained": False},
        "requester": {"class_name": "Reference", "is_contained": False},
        "requestedPerformer": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "owner": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "location": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "insurance": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "relevantHistory": {"class_name": "Reference", "is_contained": False},
        "restriction": {"class_name": "Restriction", "is_contained": True},
        "input": {"class_name": "Input", "is_contained": True},
        "output": {"class_name": "Output", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: "str" = None,
        instantiatesUri: "str" = None,
        basedOn: list["Reference"] = None,
        groupIdentifier: "Identifier" = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        statusReason: "CodeableReference" = None,
        businessStatus: "CodeableConcept" = None,
        intent: "str" = None,
        priority: "str" = None,
        doNotPerform: "bool" = None,
        code: "CodeableConcept" = None,
        description: "str" = None,
        focus: "Reference" = None,
        _for: "Reference" = None,
        encounter: "Reference" = None,
        requestedPeriod: "Period" = None,
        executionPeriod: "Period" = None,
        authoredOn: "str" = None,
        lastModified: "str" = None,
        requester: "Reference" = None,
        requestedPerformer: list["CodeableReference"] = None,
        owner: "Reference" = None,
        performer: list["Performer"] = None,
        location: "Reference" = None,
        reason: list["CodeableReference"] = None,
        insurance: list["Reference"] = None,
        note: list["Annotation"] = None,
        relevantHistory: list["Reference"] = None,
        restriction: "Restriction" = None,
        input: list["Input"] = None,
        output: list["Output"] = None,
    ):

        self.resourceType = "Task"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical
        self.instantiatesUri = instantiatesUri
        self.basedOn = basedOn or []
        self.groupIdentifier = groupIdentifier
        self.partOf = partOf or []
        self.status = status
        self.statusReason = statusReason
        self.businessStatus = businessStatus
        self.intent = intent
        self.priority = priority
        self.doNotPerform = doNotPerform
        self.code = code
        self.description = description
        self.focus = focus
        self._for = _for
        self.encounter = encounter
        self.requestedPeriod = requestedPeriod
        self.executionPeriod = executionPeriod
        self.authoredOn = authoredOn
        self.lastModified = lastModified
        self.requester = requester
        self.requestedPerformer = requestedPerformer or []
        self.owner = owner
        self.performer = performer or []
        self.location = location
        self.reason = reason or []
        self.insurance = insurance or []
        self.note = note or []
        self.relevantHistory = relevantHistory or []
        self.restriction = restriction
        self.input = input or []
        self.output = output or []

    @classmethod
    def from_dict(cls, data: dict) -> "Task":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Task":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicinalProductDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.CodeableReference import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.MarketingStatus import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Contact(FhirBaseModel):
    """A product specific contact, person (in a role), or an organization.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Allows the contact to be classified, for example QPPV, Pharmacovigilance Enquiry Information
    :param Reference contact: A product specific contact, person (in a role), or an organization
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "contact": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        contact: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.contact = contact

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class NamePart(FhirBaseModel):
    """Coding words or phrases of the name.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str part: A fragment of a product name
    :param CodeableConcept type: Identifying type for this part of the name (e.g. strength part)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        part: "str" = None,
        type: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.part = part
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CountryLanguage(FhirBaseModel):
    """Country and jurisdiction where the name applies, and associated language.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept country: Country code for where this name applies
    :param CodeableConcept jurisdiction: Jurisdiction code for where this name applies
    :param CodeableConcept language: Language code for this name
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        country: "CodeableConcept" = None,
        jurisdiction: "CodeableConcept" = None,
        language: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.country = country
        self.jurisdiction = jurisdiction
        self.language = language

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Name(FhirBaseModel):
    """The product's name, including full name and possibly coded parts.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str productName: The full product name
    :param CodeableConcept type: Type of product name, such as rINN, BAN, Proprietary, Non-Proprietary
    :param NamePart namePart: Coding words or phrases of the name
    :param CountryLanguage countryLanguage: Country and jurisdiction where the name applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "namePart": {"class_name": "NamePart", "is_contained": True},
        "countryLanguage": {"class_name": "CountryLanguage", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        productName: "str" = None,
        type: "CodeableConcept" = None,
        namePart: list["NamePart"] = None,
        countryLanguage: list["CountryLanguage"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.productName = productName
        self.type = type
        self.namePart = namePart or []
        self.countryLanguage = countryLanguage or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CrossReference(FhirBaseModel):
    """Reference to another product, e.g. for linking authorised to investigational product, or a virtual product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference product: Reference to another product, e.g. for linking authorised to investigational product
    :param CodeableConcept type: The type of relationship, for instance branded to generic or virtual to actual product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "product": {"class_name": "CodeableReference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        product: "CodeableReference" = None,
        type: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.product = product
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Operation(FhirBaseModel):
    """A manufacturing or administrative process or step associated with (or performed on) the medicinal product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference type: The type of manufacturing operation e.g. manufacturing itself, re-packaging
    :param Period effectiveDate: Date range of applicability
    :param Reference organization: The organization responsible for the particular process, e.g. the manufacturer or importer
    :param CodeableConcept confidentialityIndicator: Specifies whether this process is considered proprietary or confidential
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableReference", "is_contained": False},
        "effectiveDate": {"class_name": "Period", "is_contained": False},
        "organization": {"class_name": "Reference", "is_contained": False},
        "confidentialityIndicator": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableReference" = None,
        effectiveDate: "Period" = None,
        organization: list["Reference"] = None,
        confidentialityIndicator: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.effectiveDate = effectiveDate
        self.organization = organization or []
        self.confidentialityIndicator = confidentialityIndicator

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Characteristic(FhirBaseModel):
    """Allows the key product features to be recorded, such as "sugar free", "modified release", "parallel import".:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: A code expressing the type of characteristic
    :param CodeableConcept valueCodeableConcept: A value for the characteristic
    :param Quantity valueQuantity: A value for the characteristic
    :param str valueDate: A value for the characteristic
    :param bool valueBoolean: A value for the characteristic
    :param Attachment valueAttachment: A value for the characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueDate: "str" = None,
        valueBoolean: "bool" = None,
        valueAttachment: "Attachment" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueDate = valueDate
        self.valueBoolean = valueBoolean
        self.valueAttachment = valueAttachment

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicinalProductDefinition(DomainResource):
    """Detailed definition of a medicinal product, typically for uses other than direct patient care (e.g. regulatory use, drug catalogs, to support prescribing, adverse events management etc.).
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for this product. Could be an MPID
    :param CodeableConcept type: Regulatory type, e.g. Investigational or Authorized
    :param CodeableConcept domain: If this medicine applies to human or veterinary uses
    :param str version: A business identifier relating to a specific version of the product
    :param CodeableConcept status: The status within the lifecycle of this product record
    :param str statusDate: The date at which the given status became applicable
    :param str description: General description of this product
    :param CodeableConcept combinedPharmaceuticalDoseForm: The dose form for a single part product, or combined form of a multiple part product
    :param CodeableConcept route: The path by which the product is taken into or makes contact with the body
    :param str indication: Description of indication(s) for this product, used when structured indications are not required
    :param CodeableConcept legalStatusOfSupply: The legal status of supply of the medicinal product as classified by the regulator
    :param CodeableConcept additionalMonitoringIndicator: Whether the Medicinal Product is subject to additional monitoring for regulatory reasons
    :param CodeableConcept specialMeasures: Whether the Medicinal Product is subject to special measures for regulatory reasons
    :param CodeableConcept pediatricUseIndicator: If authorised for use in children
    :param CodeableConcept classification: Allows the product to be classified by various systems
    :param MarketingStatus marketingStatus: Marketing status of the medicinal product, in contrast to marketing authorization
    :param CodeableConcept packagedMedicinalProduct: Package type for the product
    :param CodeableConcept ingredient: The ingredients of this medicinal product - when not detailed in other resources
    :param CodeableReference impurity: Any component of the drug product which is not the chemical entity defined as the drug substance, or an excipient in the drug product
    :param Reference attachedDocument: Additional documentation about the medicinal product
    :param Reference masterFile: A master file for the medicinal product (e.g. Pharmacovigilance System Master File)
    :param Contact contact: A product specific contact, person (in a role), or an organization
    :param Reference clinicalTrial: Clinical trials or studies that this product is involved in
    :param Coding code: A code that this product is known by, within some formal terminology
    :param Name name: The product's name, including full name and possibly coded parts
    :param CrossReference crossReference: Reference to another product, e.g. for linking authorised to investigational product
    :param Operation operation: A manufacturing or administrative process for the medicinal product
    :param Characteristic characteristic: Key product features such as "sugar free", "modified release"
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "domain": {"class_name": "CodeableConcept", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "combinedPharmaceuticalDoseForm": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "route": {"class_name": "CodeableConcept", "is_contained": False},
        "legalStatusOfSupply": {"class_name": "CodeableConcept", "is_contained": False},
        "additionalMonitoringIndicator": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "specialMeasures": {"class_name": "CodeableConcept", "is_contained": False},
        "pediatricUseIndicator": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "classification": {"class_name": "CodeableConcept", "is_contained": False},
        "marketingStatus": {"class_name": "MarketingStatus", "is_contained": False},
        "packagedMedicinalProduct": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "ingredient": {"class_name": "CodeableConcept", "is_contained": False},
        "impurity": {"class_name": "CodeableReference", "is_contained": False},
        "attachedDocument": {"class_name": "Reference", "is_contained": False},
        "masterFile": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "Contact", "is_contained": True},
        "clinicalTrial": {"class_name": "Reference", "is_contained": False},
        "code": {"class_name": "Coding", "is_contained": False},
        "name": {"class_name": "Name", "is_contained": True},
        "crossReference": {"class_name": "CrossReference", "is_contained": True},
        "operation": {"class_name": "Operation", "is_contained": True},
        "characteristic": {"class_name": "Characteristic", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "CodeableConcept" = None,
        domain: "CodeableConcept" = None,
        version: "str" = None,
        status: "CodeableConcept" = None,
        statusDate: "str" = None,
        description: "str" = None,
        combinedPharmaceuticalDoseForm: "CodeableConcept" = None,
        route: list["CodeableConcept"] = None,
        indication: "str" = None,
        legalStatusOfSupply: "CodeableConcept" = None,
        additionalMonitoringIndicator: "CodeableConcept" = None,
        specialMeasures: list["CodeableConcept"] = None,
        pediatricUseIndicator: "CodeableConcept" = None,
        classification: list["CodeableConcept"] = None,
        marketingStatus: list["MarketingStatus"] = None,
        packagedMedicinalProduct: list["CodeableConcept"] = None,
        ingredient: list["CodeableConcept"] = None,
        impurity: list["CodeableReference"] = None,
        attachedDocument: list["Reference"] = None,
        masterFile: list["Reference"] = None,
        contact: list["Contact"] = None,
        clinicalTrial: list["Reference"] = None,
        code: list["Coding"] = None,
        name: list["Name"] = None,
        crossReference: list["CrossReference"] = None,
        operation: list["Operation"] = None,
        characteristic: list["Characteristic"] = None,
    ):

        self.resourceType = "MedicinalProductDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.domain = domain
        self.version = version
        self.status = status
        self.statusDate = statusDate
        self.description = description
        self.combinedPharmaceuticalDoseForm = combinedPharmaceuticalDoseForm
        self.route = route or []
        self.indication = indication
        self.legalStatusOfSupply = legalStatusOfSupply
        self.additionalMonitoringIndicator = additionalMonitoringIndicator
        self.specialMeasures = specialMeasures or []
        self.pediatricUseIndicator = pediatricUseIndicator
        self.classification = classification or []
        self.marketingStatus = marketingStatus or []
        self.packagedMedicinalProduct = packagedMedicinalProduct or []
        self.ingredient = ingredient or []
        self.impurity = impurity or []
        self.attachedDocument = attachedDocument or []
        self.masterFile = masterFile or []
        self.contact = contact or []
        self.clinicalTrial = clinicalTrial or []
        self.code = code or []
        self.name = name or []
        self.crossReference = crossReference or []
        self.operation = operation or []
        self.characteristic = characteristic or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MarketingStatus. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Period import *


class MarketingStatus(FhirBaseModel):
    """Base StructureDefinition for MarketingStatus Type: The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept country: The country in which the marketing authorisation has been granted shall be specified It should be specified using the ISO 3166 ‑ 1 alpha-2 code elements
    :param CodeableConcept jurisdiction: Where a Medicines Regulatory Agency has granted a marketing authorisation for which specific provisions within a jurisdiction apply, the jurisdiction can be specified using an appropriate controlled terminology The controlled term and the controlled term identifier shall be specified
    :param CodeableConcept status: This attribute provides information on the status of the marketing of the medicinal product See ISO/TS 20443 for more information and examples
    :param Period dateRange: The date when the Medicinal Product is placed on the market by the Marketing Authorisation Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain
    :param str restoreDate: The date when the Medicinal Product is placed on the market by the Marketing Authorisation Holder (or where applicable, the manufacturer/distributor) in a country and/or jurisdiction shall be provided A complete date consisting of day, month and year shall be specified using the ISO 8601 date format NOTE “Placed on the market” refers to the release of the Medicinal Product into the distribution chain
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "dateRange": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        country: "CodeableConcept" = None,
        jurisdiction: "CodeableConcept" = None,
        status: "CodeableConcept" = None,
        dateRange: "Period" = None,
        restoreDate: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.country = country
        self.jurisdiction = jurisdiction
        self.status = status
        self.dateRange = dateRange
        self.restoreDate = restoreDate

    @classmethod
    def from_dict(cls, data: dict) -> "MarketingStatus":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MarketingStatus":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ConditionDefinition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Observation(FhirBaseModel):
    """Observations particularly relevant to this condition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: Category that is relevant
    :param CodeableConcept code: Code for relevant Observation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        code: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.code = code

    @classmethod
    def from_dict(cls, data: dict) -> "ConditionDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConditionDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Medication(FhirBaseModel):
    """Medications particularly relevant for this condition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: Category that is relevant
    :param CodeableConcept code: Code for relevant Medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        code: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.code = code

    @classmethod
    def from_dict(cls, data: dict) -> "ConditionDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConditionDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Precondition(FhirBaseModel):
    """An observation that suggests that this condition applies.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: sensitive | specific
    :param CodeableConcept code: Code for relevant Observation
    :param CodeableConcept valueCodeableConcept: Value of Observation
    :param Quantity valueQuantity: Value of Observation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        code: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.code = code
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity

    @classmethod
    def from_dict(cls, data: dict) -> "ConditionDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConditionDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Questionnaire(FhirBaseModel):
    """Questionnaire for this condition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str purpose: preadmit | diff-diagnosis | outcome
    :param Reference reference: Specific Questionnaire
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        purpose: "str" = None,
        reference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.purpose = purpose
        self.reference = reference

    @classmethod
    def from_dict(cls, data: dict) -> "ConditionDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConditionDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Plan(FhirBaseModel):
    """Plan that is appropriate.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept role: Use for the plan
    :param Reference reference: The actual plan
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        role: "CodeableConcept" = None,
        reference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.role = role
        self.reference = reference

    @classmethod
    def from_dict(cls, data: dict) -> "ConditionDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConditionDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ConditionDefinition(DomainResource):
    """A definition of a condition and information relevant to managing it.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this condition definition, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the condition definition
    :param str version: Business version of the condition definition
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this condition definition (computer friendly)
    :param str title: Name for this condition definition (human friendly)
    :param str subtitle: Subordinate title of the event definition
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the condition definition
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for condition definition (if applicable)
    :param CodeableConcept code: Identification of the condition, problem or diagnosis
    :param CodeableConcept severity: Subjective severity of condition
    :param CodeableConcept bodySite: Anatomical location, if relevant
    :param CodeableConcept stage: Stage/grade, usually assessed formally
    :param bool hasSeverity: Whether Severity is appropriate
    :param bool hasBodySite: Whether bodySite is appropriate
    :param bool hasStage: Whether stage is appropriate
    :param str definition: Formal Definition for the condition
    :param Observation observation: Observations particularly relevant to this condition
    :param Medication medication: Medications particularly relevant for this condition
    :param Precondition precondition: Observation that suggets this condition
    :param Reference team: Appropriate team for this condition
    :param Questionnaire questionnaire: Questionnaire for this condition
    :param Plan plan: Plan that is appropriate
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "severity": {"class_name": "CodeableConcept", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "stage": {"class_name": "CodeableConcept", "is_contained": False},
        "observation": {"class_name": "Observation", "is_contained": True},
        "medication": {"class_name": "Medication", "is_contained": True},
        "precondition": {"class_name": "Precondition", "is_contained": True},
        "team": {"class_name": "Reference", "is_contained": False},
        "questionnaire": {"class_name": "Questionnaire", "is_contained": True},
        "plan": {"class_name": "Plan", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        subtitle: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        severity: "CodeableConcept" = None,
        bodySite: "CodeableConcept" = None,
        stage: "CodeableConcept" = None,
        hasSeverity: "bool" = None,
        hasBodySite: "bool" = None,
        hasStage: "bool" = None,
        definition: list["str"] = None,
        observation: list["Observation"] = None,
        medication: list["Medication"] = None,
        precondition: list["Precondition"] = None,
        team: list["Reference"] = None,
        questionnaire: list["Questionnaire"] = None,
        plan: list["Plan"] = None,
    ):

        self.resourceType = "ConditionDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.subtitle = subtitle
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.code = code
        self.severity = severity
        self.bodySite = bodySite
        self.stage = stage
        self.hasSeverity = hasSeverity
        self.hasBodySite = hasBodySite
        self.hasStage = hasStage
        self.definition = definition or []
        self.observation = observation or []
        self.medication = medication or []
        self.precondition = precondition or []
        self.team = team or []
        self.questionnaire = questionnaire or []
        self.plan = plan or []

    @classmethod
    def from_dict(cls, data: dict) -> "ConditionDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ConditionDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Encounter. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Duration import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class StatusHistory(FhirBaseModel):
    """The status history permits the encounter resource to contain the status history without needing to read through the historical versions of the resource, or even have the server store them.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str status: planned | arrived | triaged | in-progress | onleave | finished | cancelled +
    :param Period period: The time that the episode was in the specified status
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        status: "str" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.status = status
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ClassHistory(FhirBaseModel):
    """The class history permits the tracking of the encounters transitions without needing to go  through the resource history.  This would be used for a case where an admission starts of as an emergency encounter, then transitions into an inpatient scenario. Doing this and not restarting a new encounter ensures that any lab/diagnostic results can more easily follow the patient and not require re-processing and not get lost or cancelled during a kind of discharge from emergency to inpatient.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Coding _class: inpatient | outpatient | ambulatory | emergency +
    :param Period period: The time that the episode was in the specified class
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "_class": {"class_name": "Coding", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        _class: "Coding" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self._class = _class
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Participant(FhirBaseModel):
    """The list of people responsible for providing the service.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Role of participant in encounter
    :param Period period: Period of time during the encounter that the participant participated
    :param Reference individual: Persons involved in the encounter other than the patient
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "individual": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: list["CodeableConcept"] = None,
        period: "Period" = None,
        individual: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type or []
        self.period = period
        self.individual = individual

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Diagnosis(FhirBaseModel):
    """The list of diagnosis relevant to this encounter.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference condition: The diagnosis or procedure relevant to the encounter
    :param CodeableConcept use: Role that this diagnosis has within the encounter (e.g. admission, billing, discharge …)
    :param int rank: Ranking of the diagnosis (for each role type)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "condition": {"class_name": "Reference", "is_contained": False},
        "use": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        condition: "Reference" = None,
        use: "CodeableConcept" = None,
        rank: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.condition = condition
        self.use = use
        self.rank = rank

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Hospitalization(FhirBaseModel):
    """Details about the admission to a healthcare service.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier preAdmissionIdentifier: Pre-admission identifier
    :param Reference origin: The location/organization from which the patient came before admission
    :param CodeableConcept admitSource: From where patient was admitted (physician referral, transfer)
    :param CodeableConcept reAdmission: The type of hospital re-admission that has occurred (if any). If the value is absent, then this is not identified as a readmission
    :param CodeableConcept dietPreference: Diet preferences reported by the patient
    :param CodeableConcept specialCourtesy: Special courtesies (VIP, board member)
    :param CodeableConcept specialArrangement: Wheelchair, translator, stretcher, etc.
    :param Reference destination: Location/organization to which the patient is discharged
    :param CodeableConcept dischargeDisposition: Category or kind of location after discharge
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "preAdmissionIdentifier": {"class_name": "Identifier", "is_contained": False},
        "origin": {"class_name": "Reference", "is_contained": False},
        "admitSource": {"class_name": "CodeableConcept", "is_contained": False},
        "reAdmission": {"class_name": "CodeableConcept", "is_contained": False},
        "dietPreference": {"class_name": "CodeableConcept", "is_contained": False},
        "specialCourtesy": {"class_name": "CodeableConcept", "is_contained": False},
        "specialArrangement": {"class_name": "CodeableConcept", "is_contained": False},
        "destination": {"class_name": "Reference", "is_contained": False},
        "dischargeDisposition": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        preAdmissionIdentifier: "Identifier" = None,
        origin: "Reference" = None,
        admitSource: "CodeableConcept" = None,
        reAdmission: "CodeableConcept" = None,
        dietPreference: list["CodeableConcept"] = None,
        specialCourtesy: list["CodeableConcept"] = None,
        specialArrangement: list["CodeableConcept"] = None,
        destination: "Reference" = None,
        dischargeDisposition: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.preAdmissionIdentifier = preAdmissionIdentifier
        self.origin = origin
        self.admitSource = admitSource
        self.reAdmission = reAdmission
        self.dietPreference = dietPreference or []
        self.specialCourtesy = specialCourtesy or []
        self.specialArrangement = specialArrangement or []
        self.destination = destination
        self.dischargeDisposition = dischargeDisposition

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Location(FhirBaseModel):
    """List of locations where  the patient has been during this encounter.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference location: Location the encounter takes place
    :param str status: planned | active | reserved | completed
    :param CodeableConcept physicalType: The physical type of the location (usually the level in the location hierachy - bed room ward etc.)
    :param Period period: Time period during which the patient was present at the location
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "physicalType": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        location: "Reference" = None,
        status: "str" = None,
        physicalType: "CodeableConcept" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.location = location
        self.status = status
        self.physicalType = physicalType
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Encounter(DomainResource):
    """An interaction between a patient and healthcare provider(s) for the purpose of providing healthcare service(s) or assessing the health status of a patient.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifier(s) by which this encounter is known
    :param str status: planned | arrived | triaged | in-progress | onleave | finished | cancelled +
    :param StatusHistory statusHistory: List of past encounter statuses
    :param Coding _class: Classification of patient encounter
    :param ClassHistory classHistory: List of past encounter classes
    :param CodeableConcept type: Specific type of encounter
    :param CodeableConcept serviceType: Specific type of service
    :param CodeableConcept priority: Indicates the urgency of the encounter
    :param Reference subject: The patient or group present at the encounter
    :param Reference episodeOfCare: Episode(s) of care that this encounter should be recorded against
    :param Reference basedOn: The ServiceRequest that initiated this encounter
    :param Participant participant: List of participants involved in the encounter
    :param Reference appointment: The appointment that scheduled this encounter
    :param Period period: The start and end time of the encounter
    :param Duration length: Quantity of time the encounter lasted (less time absent)
    :param CodeableConcept reasonCode: Coded reason the encounter takes place
    :param Reference reasonReference: Reason the encounter takes place (reference)
    :param Diagnosis diagnosis: The list of diagnosis relevant to this encounter
    :param Reference account: The set of accounts that may be used for billing for this Encounter
    :param Hospitalization hospitalization: Details about the admission to a healthcare service
    :param Location location: List of locations where the patient has been
    :param Reference serviceProvider: The organization (facility) responsible for this encounter
    :param Reference partOf: Another Encounter this encounter is part of
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "statusHistory": {"class_name": "StatusHistory", "is_contained": True},
        "_class": {"class_name": "Coding", "is_contained": False},
        "classHistory": {"class_name": "ClassHistory", "is_contained": True},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "serviceType": {"class_name": "CodeableConcept", "is_contained": False},
        "priority": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "episodeOfCare": {"class_name": "Reference", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "participant": {"class_name": "Participant", "is_contained": True},
        "appointment": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "length": {"class_name": "Duration", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "diagnosis": {"class_name": "Diagnosis", "is_contained": True},
        "account": {"class_name": "Reference", "is_contained": False},
        "hospitalization": {"class_name": "Hospitalization", "is_contained": True},
        "location": {"class_name": "Location", "is_contained": True},
        "serviceProvider": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        statusHistory: list["StatusHistory"] = None,
        _class: "Coding" = None,
        classHistory: list["ClassHistory"] = None,
        type: list["CodeableConcept"] = None,
        serviceType: "CodeableConcept" = None,
        priority: "CodeableConcept" = None,
        subject: "Reference" = None,
        episodeOfCare: list["Reference"] = None,
        basedOn: list["Reference"] = None,
        participant: list["Participant"] = None,
        appointment: list["Reference"] = None,
        period: "Period" = None,
        length: "Duration" = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        diagnosis: list["Diagnosis"] = None,
        account: list["Reference"] = None,
        hospitalization: "Hospitalization" = None,
        location: list["Location"] = None,
        serviceProvider: "Reference" = None,
        partOf: "Reference" = None,
    ):

        self.resourceType = "Encounter"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.statusHistory = statusHistory or []
        self._class = _class
        self.classHistory = classHistory or []
        self.type = type or []
        self.serviceType = serviceType
        self.priority = priority
        self.subject = subject
        self.episodeOfCare = episodeOfCare or []
        self.basedOn = basedOn or []
        self.participant = participant or []
        self.appointment = appointment or []
        self.period = period
        self.length = length
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.diagnosis = diagnosis or []
        self.account = account or []
        self.hospitalization = hospitalization
        self.location = location or []
        self.serviceProvider = serviceProvider
        self.partOf = partOf

    @classmethod
    def from_dict(cls, data: dict) -> "Encounter":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Encounter":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ImagingStudy. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Performer(FhirBaseModel):
    """Indicates who or what performed the series and how they were involved.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Type of performance
    :param Reference actor: Who performed the series
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Instance(FhirBaseModel):
    """A single SOP instance within the series, e.g. an image, or presentation state.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str uid: DICOM SOP Instance UID
    :param Coding sopClass: DICOM class type
    :param int number: The number of this instance in the series
    :param str title: Description of instance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "sopClass": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        uid: "str" = None,
        sopClass: "Coding" = None,
        number: "int" = None,
        title: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.uid = uid
        self.sopClass = sopClass
        self.number = number
        self.title = title

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Series(FhirBaseModel):
    """Each study has one or more series of images or other content.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str uid: DICOM Series Instance UID for the series
    :param int number: Numeric identifier of this series
    :param Coding modality: The modality of the instances in the series
    :param str description: A short human readable summary of the series
    :param int numberOfInstances: Number of Series Related Instances
    :param Reference endpoint: Series access endpoint
    :param Coding bodySite: Body part examined
    :param Coding laterality: Body part laterality
    :param Reference specimen: Specimen imaged
    :param str started: When the series started
    :param Performer performer: Who performed the series
    :param Instance instance: A single SOP instance from the series
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "modality": {"class_name": "Coding", "is_contained": False},
        "endpoint": {"class_name": "Reference", "is_contained": False},
        "bodySite": {"class_name": "Coding", "is_contained": False},
        "laterality": {"class_name": "Coding", "is_contained": False},
        "specimen": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "instance": {"class_name": "Instance", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        uid: "str" = None,
        number: "int" = None,
        modality: "Coding" = None,
        description: "str" = None,
        numberOfInstances: "int" = None,
        endpoint: list["Reference"] = None,
        bodySite: "Coding" = None,
        laterality: "Coding" = None,
        specimen: list["Reference"] = None,
        started: "str" = None,
        performer: list["Performer"] = None,
        instance: list["Instance"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.uid = uid
        self.number = number
        self.modality = modality
        self.description = description
        self.numberOfInstances = numberOfInstances
        self.endpoint = endpoint or []
        self.bodySite = bodySite
        self.laterality = laterality
        self.specimen = specimen or []
        self.started = started
        self.performer = performer or []
        self.instance = instance or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ImagingStudy(DomainResource):
    """Representation of the content produced in a DICOM imaging study. A study comprises a set of series, each of which includes a set of Service-Object Pair Instances (SOP Instances - images or other data) acquired or produced in a common context.  A series is of only one modality (e.g. X-ray, CT, MR, ultrasound), but a study may have multiple series of different modalities.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifiers for the whole study
    :param str status: registered | available | cancelled | entered-in-error | unknown
    :param Coding modality: All series modality if actual acquisition modalities
    :param Reference subject: Who or what is the subject of the study
    :param Reference encounter: Encounter with which this imaging study is associated
    :param str started: When the study was started
    :param Reference basedOn: Request fulfilled
    :param Reference referrer: Referring physician
    :param Reference interpreter: Who interpreted images
    :param Reference endpoint: Study access endpoint
    :param int numberOfSeries: Number of Study Related Series
    :param int numberOfInstances: Number of Study Related Instances
    :param Reference procedureReference: The performed Procedure reference
    :param CodeableConcept procedureCode: The performed procedure code
    :param Reference location: Where ImagingStudy occurred
    :param CodeableConcept reasonCode: Why the study was requested
    :param Reference reasonReference: Why was study performed
    :param Annotation note: User-defined comments
    :param str description: Institution-generated description
    :param Series series: Each study has one or more series of instances
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "modality": {"class_name": "Coding", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "referrer": {"class_name": "Reference", "is_contained": False},
        "interpreter": {"class_name": "Reference", "is_contained": False},
        "endpoint": {"class_name": "Reference", "is_contained": False},
        "procedureReference": {"class_name": "Reference", "is_contained": False},
        "procedureCode": {"class_name": "CodeableConcept", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "series": {"class_name": "Series", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        modality: list["Coding"] = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        started: "str" = None,
        basedOn: list["Reference"] = None,
        referrer: "Reference" = None,
        interpreter: list["Reference"] = None,
        endpoint: list["Reference"] = None,
        numberOfSeries: "int" = None,
        numberOfInstances: "int" = None,
        procedureReference: "Reference" = None,
        procedureCode: list["CodeableConcept"] = None,
        location: "Reference" = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        note: list["Annotation"] = None,
        description: "str" = None,
        series: list["Series"] = None,
    ):

        self.resourceType = "ImagingStudy"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.modality = modality or []
        self.subject = subject
        self.encounter = encounter
        self.started = started
        self.basedOn = basedOn or []
        self.referrer = referrer
        self.interpreter = interpreter or []
        self.endpoint = endpoint or []
        self.numberOfSeries = numberOfSeries
        self.numberOfInstances = numberOfInstances
        self.procedureReference = procedureReference
        self.procedureCode = procedureCode or []
        self.location = location
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.note = note or []
        self.description = description
        self.series = series or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DocumentReference. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Attester(FhirBaseModel):
    """A participant who has authenticated the accuracy of the document.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept mode: personal | professional | legal | official
    :param str time: When the document was attested
    :param Reference party: Who attested the document
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "mode": {"class_name": "CodeableConcept", "is_contained": False},
        "party": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        mode: "CodeableConcept" = None,
        time: "str" = None,
        party: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.mode = mode
        self.time = time
        self.party = party

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RelatesTo(FhirBaseModel):
    """Relationships that this document has with other document references that already exist.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: The relationship type with another document
    :param Reference target: Target of the relationship
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "target": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        target: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.target = target

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Profile(FhirBaseModel):
    """An identifier of the document constraints, encoding, structure, and template that the document conforms to beyond the base format indicated in the mimeType.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Coding valueCoding: Code|uri|canonical
    :param str valueUri: Code|uri|canonical
    :param str valueCanonical: Code|uri|canonical
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "valueCoding": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        valueCoding: "Coding" = None,
        valueUri: "str" = None,
        valueCanonical: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.valueCoding = valueCoding
        self.valueUri = valueUri
        self.valueCanonical = valueCanonical

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Content(FhirBaseModel):
    """The document and format referenced.  If there are multiple content element repetitions, these must all represent the same document in different format, or attachment metadata.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Attachment attachment: Where to access the document
    :param Profile profile: Content profile rules for the document
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "attachment": {"class_name": "Attachment", "is_contained": False},
        "profile": {"class_name": "Profile", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        attachment: "Attachment" = None,
        profile: list["Profile"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.attachment = attachment
        self.profile = profile or []

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DocumentReference(DomainResource):
    """A reference to a document of any kind for any purpose. While the term “document” implies a more narrow focus, for this resource this “document” encompasses *any* serialized object with a mime-type, it includes formal patient-centric documents (CDA), clinical notes, scanned paper, non-patient specific documents like policy text, as well as a photo, video, or audio recording acquired or used in healthcare.  The DocumentReference resource provides metadata about the document so that the document can be discovered and managed.  The actual content may be inline base64 encoded data or provided by direct reference.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifiers for the document
    :param str version: An explicitly assigned identifer of a variation of the content in the DocumentReference
    :param Reference basedOn: Procedure that caused this media to be created
    :param str status: current | superseded | entered-in-error
    :param str docStatus: registered | partial | preliminary | final | amended | corrected | appended | cancelled | entered-in-error | deprecated | unknown
    :param CodeableConcept modality: Imaging modality used
    :param CodeableConcept type: Kind of document (LOINC if possible)
    :param CodeableConcept category: Categorization of document
    :param Reference subject: Who/what is the subject of the document
    :param Reference context: Context of the document content
    :param CodeableReference event: Main clinical acts documented
    :param CodeableReference bodySite: Body part included
    :param CodeableConcept facilityType: Kind of facility where patient was seen
    :param CodeableConcept practiceSetting: Additional details about where the content was created (e.g. clinical specialty)
    :param Period period: Time of service that is being documented
    :param str date: When this document reference was created
    :param Reference author: Who and/or what authored the document
    :param Attester attester: Attests to accuracy of the document
    :param Reference custodian: Organization which maintains the document
    :param RelatesTo relatesTo: Relationships to other documents
    :param str description: Human-readable description
    :param CodeableConcept securityLabel: Document security-tags
    :param Content content: Document referenced
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "modality": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "context": {"class_name": "Reference", "is_contained": False},
        "event": {"class_name": "CodeableReference", "is_contained": False},
        "bodySite": {"class_name": "CodeableReference", "is_contained": False},
        "facilityType": {"class_name": "CodeableConcept", "is_contained": False},
        "practiceSetting": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "attester": {"class_name": "Attester", "is_contained": True},
        "custodian": {"class_name": "Reference", "is_contained": False},
        "relatesTo": {"class_name": "RelatesTo", "is_contained": True},
        "securityLabel": {"class_name": "CodeableConcept", "is_contained": False},
        "content": {"class_name": "Content", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        basedOn: list["Reference"] = None,
        status: "str" = None,
        docStatus: "str" = None,
        modality: list["CodeableConcept"] = None,
        type: "CodeableConcept" = None,
        category: list["CodeableConcept"] = None,
        subject: "Reference" = None,
        context: list["Reference"] = None,
        event: list["CodeableReference"] = None,
        bodySite: list["CodeableReference"] = None,
        facilityType: "CodeableConcept" = None,
        practiceSetting: "CodeableConcept" = None,
        period: "Period" = None,
        date: "str" = None,
        author: list["Reference"] = None,
        attester: list["Attester"] = None,
        custodian: "Reference" = None,
        relatesTo: list["RelatesTo"] = None,
        description: "str" = None,
        securityLabel: list["CodeableConcept"] = None,
        content: list["Content"] = None,
    ):

        self.resourceType = "DocumentReference"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.version = version
        self.basedOn = basedOn or []
        self.status = status
        self.docStatus = docStatus
        self.modality = modality or []
        self.type = type
        self.category = category or []
        self.subject = subject
        self.context = context or []
        self.event = event or []
        self.bodySite = bodySite or []
        self.facilityType = facilityType
        self.practiceSetting = practiceSetting
        self.period = period
        self.date = date
        self.author = author or []
        self.attester = attester or []
        self.custodian = custodian
        self.relatesTo = relatesTo or []
        self.description = description
        self.securityLabel = securityLabel or []
        self.content = content or []

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SubstanceDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Ratio import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Moiety(FhirBaseModel):
    """Moiety, for structural modifications.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept role: Role that the moiety is playing
    :param Identifier identifier: Identifier by which this moiety substance is known
    :param str name: Textual name for this moiety substance
    :param CodeableConcept stereochemistry: Stereochemistry type
    :param CodeableConcept opticalActivity: Optical activity type
    :param str molecularFormula: Molecular formula for this moiety (e.g. with the Hill system)
    :param Quantity amountQuantity: Quantitative value for this moiety
    :param str amountString: Quantitative value for this moiety
    :param CodeableConcept measurementType: The measurement type of the quantitative value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "stereochemistry": {"class_name": "CodeableConcept", "is_contained": False},
        "opticalActivity": {"class_name": "CodeableConcept", "is_contained": False},
        "amountQuantity": {"class_name": "Quantity", "is_contained": False},
        "measurementType": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        role: "CodeableConcept" = None,
        identifier: "Identifier" = None,
        name: "str" = None,
        stereochemistry: "CodeableConcept" = None,
        opticalActivity: "CodeableConcept" = None,
        molecularFormula: "str" = None,
        amountQuantity: "Quantity" = None,
        amountString: "str" = None,
        measurementType: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.role = role
        self.identifier = identifier
        self.name = name
        self.stereochemistry = stereochemistry
        self.opticalActivity = opticalActivity
        self.molecularFormula = molecularFormula
        self.amountQuantity = amountQuantity
        self.amountString = amountString
        self.measurementType = measurementType

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Property(FhirBaseModel):
    """General specifications for this substance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: A code expressing the type of property
    :param CodeableConcept valueCodeableConcept: A value for the property
    :param Quantity valueQuantity: A value for the property
    :param str valueDate: A value for the property
    :param bool valueBoolean: A value for the property
    :param Attachment valueAttachment: A value for the property
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueDate: "str" = None,
        valueBoolean: "bool" = None,
        valueAttachment: "Attachment" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueDate = valueDate
        self.valueBoolean = valueBoolean
        self.valueAttachment = valueAttachment

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MolecularWeight(FhirBaseModel):
    """The molecular weight or weight range (for proteins, polymers or nucleic acids).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept method: The method by which the weight was determined
    :param CodeableConcept type: Type of molecular weight e.g. exact, average, weight average
    :param Quantity amount: Used to capture quantitative values for a variety of elements
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        method: "CodeableConcept" = None,
        type: "CodeableConcept" = None,
        amount: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.method = method
        self.type = type
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Representation(FhirBaseModel):
    """A depiction of the structure or characterization of the substance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The kind of structural representation (e.g. full, partial)
    :param str representation: The structural representation or characterization as a text string in a standard format
    :param CodeableConcept format: The format of the representation e.g. InChI, SMILES, MOLFILE (note: not the physical file format)
    :param Reference document: An attachment with the structural representation e.g. a structure graphic or AnIML file
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "format": {"class_name": "CodeableConcept", "is_contained": False},
        "document": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        representation: "str" = None,
        format: "CodeableConcept" = None,
        document: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.representation = representation
        self.format = format
        self.document = document

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Structure(FhirBaseModel):
    """Structural information.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept stereochemistry: Stereochemistry type
    :param CodeableConcept opticalActivity: Optical activity type
    :param str molecularFormula: Molecular formula (e.g. using the Hill system)
    :param str molecularFormulaByMoiety: Specified per moiety according to the Hill system
    :param MolecularWeight molecularWeight: The molecular weight or weight range
    :param CodeableConcept technique: The method used to find the structure e.g. X-ray, NMR
    :param Reference sourceDocument: Source of information for the structure
    :param Representation representation: A depiction of the structure or characterization of the substance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "stereochemistry": {"class_name": "CodeableConcept", "is_contained": False},
        "opticalActivity": {"class_name": "CodeableConcept", "is_contained": False},
        "molecularWeight": {"class_name": "MolecularWeight", "is_contained": True},
        "technique": {"class_name": "CodeableConcept", "is_contained": False},
        "sourceDocument": {"class_name": "Reference", "is_contained": False},
        "representation": {"class_name": "Representation", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        stereochemistry: "CodeableConcept" = None,
        opticalActivity: "CodeableConcept" = None,
        molecularFormula: "str" = None,
        molecularFormulaByMoiety: "str" = None,
        molecularWeight: "MolecularWeight" = None,
        technique: list["CodeableConcept"] = None,
        sourceDocument: list["Reference"] = None,
        representation: list["Representation"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.stereochemistry = stereochemistry
        self.opticalActivity = opticalActivity
        self.molecularFormula = molecularFormula
        self.molecularFormulaByMoiety = molecularFormulaByMoiety
        self.molecularWeight = molecularWeight
        self.technique = technique or []
        self.sourceDocument = sourceDocument or []
        self.representation = representation or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Code(FhirBaseModel):
    """Codes associated with the substance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: The specific code
    :param CodeableConcept status: Status of the code assignment, for example 'provisional', 'approved'
    :param str statusDate: The date at which the code status was changed
    :param Annotation note: Any comment can be provided in this field
    :param Reference source: Supporting literature
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        status: "CodeableConcept" = None,
        statusDate: "str" = None,
        note: list["Annotation"] = None,
        source: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.status = status
        self.statusDate = statusDate
        self.note = note or []
        self.source = source or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Official(FhirBaseModel):
    """Details of the official nature of this name.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept authority: Which authority uses this official name
    :param CodeableConcept status: The status of the official name, for example 'draft', 'active'
    :param str date: Date of official name change
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "authority": {"class_name": "CodeableConcept", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        authority: "CodeableConcept" = None,
        status: "CodeableConcept" = None,
        date: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.authority = authority
        self.status = status
        self.date = date

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Name(FhirBaseModel):
    """Names applicable to this substance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: The actual name
    :param CodeableConcept type: Name type e.g. 'systematic',  'scientific, 'brand'
    :param CodeableConcept status: The status of the name e.g. 'current', 'proposed'
    :param bool preferred: If this is the preferred name for this substance
    :param CodeableConcept language: Human language that the name is written in
    :param CodeableConcept domain: The use context of this name e.g. as an active ingredient or as a food colour additive
    :param CodeableConcept jurisdiction: The jurisdiction where this name applies
    :param Synonym synonym: A synonym of this particular name, by which the substance is also known
    :param Translation translation: A translation for this name into another human language
    :param Official official: Details of the official nature of this name
    :param Reference source: Supporting literature
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
        "domain": {"class_name": "CodeableConcept", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "synonym": {"class_name": "Synonym", "is_contained": True},
        "translation": {"class_name": "Translation", "is_contained": True},
        "official": {"class_name": "Official", "is_contained": True},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        type: "CodeableConcept" = None,
        status: "CodeableConcept" = None,
        preferred: "bool" = None,
        language: list["CodeableConcept"] = None,
        domain: list["CodeableConcept"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        synonym: list["Synonym"] = None,
        translation: list["Translation"] = None,
        official: list["Official"] = None,
        source: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.type = type
        self.status = status
        self.preferred = preferred
        self.language = language or []
        self.domain = domain or []
        self.jurisdiction = jurisdiction or []
        self.synonym = synonym or []
        self.translation = translation or []
        self.official = official or []
        self.source = source or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Relationship(FhirBaseModel):
    """A link between this substance and another, with details of the relationship.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference substanceDefinitionReference: A pointer to another substance, as a resource or a representational code
    :param CodeableConcept substanceDefinitionCodeableConcept: A pointer to another substance, as a resource or a representational code
    :param CodeableConcept type: For example "salt to parent", "active moiety"
    :param bool isDefining: For example where an enzyme strongly bonds with a particular substance, this is a defining relationship for that enzyme, out of several possible relationships
    :param Quantity amountQuantity: A numeric factor for the relationship, e.g. that a substance salt has some percentage of active substance in relation to some other
    :param Ratio amountRatio: A numeric factor for the relationship, e.g. that a substance salt has some percentage of active substance in relation to some other
    :param str amountString: A numeric factor for the relationship, e.g. that a substance salt has some percentage of active substance in relation to some other
    :param Ratio ratioHighLimitAmount: For use when the numeric has an uncertain range
    :param CodeableConcept comparator: An operator for the amount, for example "average", "approximately", "less than"
    :param Reference source: Supporting literature
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "substanceDefinitionReference": {
            "class_name": "Reference",
            "is_contained": False,
        },
        "substanceDefinitionCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "amountQuantity": {"class_name": "Quantity", "is_contained": False},
        "amountRatio": {"class_name": "Ratio", "is_contained": False},
        "ratioHighLimitAmount": {"class_name": "Ratio", "is_contained": False},
        "comparator": {"class_name": "CodeableConcept", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        substanceDefinitionReference: "Reference" = None,
        substanceDefinitionCodeableConcept: "CodeableConcept" = None,
        type: "CodeableConcept" = None,
        isDefining: "bool" = None,
        amountQuantity: "Quantity" = None,
        amountRatio: "Ratio" = None,
        amountString: "str" = None,
        ratioHighLimitAmount: "Ratio" = None,
        comparator: "CodeableConcept" = None,
        source: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.substanceDefinitionReference = substanceDefinitionReference
        self.substanceDefinitionCodeableConcept = substanceDefinitionCodeableConcept
        self.type = type
        self.isDefining = isDefining
        self.amountQuantity = amountQuantity
        self.amountRatio = amountRatio
        self.amountString = amountString
        self.ratioHighLimitAmount = ratioHighLimitAmount
        self.comparator = comparator
        self.source = source or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SourceMaterial(FhirBaseModel):
    """Material or taxonomic/anatomical source for the substance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Classification of the origin of the raw material. e.g. cat hair is an Animal source type
    :param CodeableConcept genus: The genus of an organism e.g. the Latin epithet of the plant/animal scientific name
    :param CodeableConcept species: The species of an organism e.g. the Latin epithet of the species of the plant/animal
    :param CodeableConcept part: An anatomical origin of the source material within an organism
    :param CodeableConcept countryOfOrigin: The country or countries where the material is harvested
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "genus": {"class_name": "CodeableConcept", "is_contained": False},
        "species": {"class_name": "CodeableConcept", "is_contained": False},
        "part": {"class_name": "CodeableConcept", "is_contained": False},
        "countryOfOrigin": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        genus: "CodeableConcept" = None,
        species: "CodeableConcept" = None,
        part: "CodeableConcept" = None,
        countryOfOrigin: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.genus = genus
        self.species = species
        self.part = part
        self.countryOfOrigin = countryOfOrigin or []

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubstanceDefinition(DomainResource):
    """The detailed description of a substance, typically at a level beyond what is used for prescribing.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifier by which this substance is known
    :param str version: A business level version identifier of the substance
    :param CodeableConcept status: Status of substance within the catalogue e.g. active, retired
    :param CodeableConcept classification: A categorization, high level e.g. polymer or nucleic acid, or food, chemical, biological, or lower e.g. polymer linear or branch chain, or type of impurity
    :param CodeableConcept domain: If the substance applies to human or veterinary use
    :param CodeableConcept grade: The quality standard, established benchmark, to which substance complies (e.g. USP/NF, BP)
    :param str description: Textual description of the substance
    :param Reference informationSource: Supporting literature
    :param Annotation note: Textual comment about the substance's catalogue or registry record
    :param Reference manufacturer: The entity that creates, makes, produces or fabricates the substance
    :param Reference supplier: An entity that is the source for the substance. It may be different from the manufacturer
    :param Moiety moiety: Moiety, for structural modifications
    :param Property property: General specifications for this substance
    :param MolecularWeight molecularWeight: The molecular weight or weight range
    :param Structure structure: Structural information
    :param Code code: Codes associated with the substance
    :param Name name: Names applicable to this substance
    :param Relationship relationship: A link between this substance and another
    :param SourceMaterial sourceMaterial: Material or taxonomic/anatomical source
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "classification": {"class_name": "CodeableConcept", "is_contained": False},
        "domain": {"class_name": "CodeableConcept", "is_contained": False},
        "grade": {"class_name": "CodeableConcept", "is_contained": False},
        "informationSource": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "supplier": {"class_name": "Reference", "is_contained": False},
        "moiety": {"class_name": "Moiety", "is_contained": True},
        "property": {"class_name": "Property", "is_contained": True},
        "molecularWeight": {"class_name": "MolecularWeight", "is_contained": True},
        "structure": {"class_name": "Structure", "is_contained": True},
        "code": {"class_name": "Code", "is_contained": True},
        "name": {"class_name": "Name", "is_contained": True},
        "relationship": {"class_name": "Relationship", "is_contained": True},
        "sourceMaterial": {"class_name": "SourceMaterial", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        status: "CodeableConcept" = None,
        classification: list["CodeableConcept"] = None,
        domain: "CodeableConcept" = None,
        grade: list["CodeableConcept"] = None,
        description: "str" = None,
        informationSource: list["Reference"] = None,
        note: list["Annotation"] = None,
        manufacturer: list["Reference"] = None,
        supplier: list["Reference"] = None,
        moiety: list["Moiety"] = None,
        property: list["Property"] = None,
        molecularWeight: list["MolecularWeight"] = None,
        structure: "Structure" = None,
        code: list["Code"] = None,
        name: list["Name"] = None,
        relationship: list["Relationship"] = None,
        sourceMaterial: "SourceMaterial" = None,
    ):

        self.resourceType = "SubstanceDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.version = version
        self.status = status
        self.classification = classification or []
        self.domain = domain
        self.grade = grade or []
        self.description = description
        self.informationSource = informationSource or []
        self.note = note or []
        self.manufacturer = manufacturer or []
        self.supplier = supplier or []
        self.moiety = moiety or []
        self.property = property or []
        self.molecularWeight = molecularWeight or []
        self.structure = structure
        self.code = code or []
        self.name = name or []
        self.relationship = relationship or []
        self.sourceMaterial = sourceMaterial

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
